Learn R Programming

saturnin (version 1.1.1)

account.for.prior: Accounting for prior edge appearance probability.

Description

The function transforms the posterior edge appearance probability matrix given by edge.prob to account for prior edge appearance probability. For further details on the transformation, we refer the reader to the paper quoted in the references section. The function can be directly applied in edge.prob by setting account.prior to TRUE.

Usage

account.for.prior(prob, q0)

Arguments

prob
Posterior edge appearance probability matrix.
q0
Desired prior edge appearance probability.

Value

prob.q0
Transformed posterior edge appearance probability matrix.

References

This package implements the method described in the paper "Bayesian Inference of Graphical Model Structures Using Trees" by L. Schwaller, S. Robin, M. Stumpf, 2015 (submitted and availavable on arXiv).

Examples

Run this code
library('saturnin')
data(data_gaussian)

W <- lweights_gaussian(data_gaussian)
prob <- edge.prob(W, log = TRUE)

prob.q0 <- account.for.prior(prob, q0 = 0.5)

Run the code above in your browser using DataLab