Learn R Programming

saturnin (version 1.1.1)

edge.prob: Computation of posterior edge appearance probabilities in a random tree.

Description

The function computes posterior edge appearance probabilities in a random tree from a (log-)weight matrix. The (log-)weight matrix can be obtained from one of the functions lweights_multinomial, lweights_gaussian or weights_gausscopula. The function can also account for prior edge appearance probability.

Usage

edge.prob(W, log = TRUE, account.prior = FALSE, q0 = 0.5)

Arguments

W
(log-)weight matrix
log
TRUE when using a log-weight matrix, FALSE otherwise.
account.prior
FALSE for no accounting, TRUE otherwise.
q0
Desired prior edge appearance probability.

Value

prob
Posterior edge appearance probability matrix.

References

This package implements the method described in the paper "Bayesian Inference of Graphical Model Structures Using Trees" by L. Schwaller, S. Robin, M. Stumpf, 2015 (submitted and availavable on arXiv).

Examples

Run this code
library('saturnin')
data(data_gaussian)

W <- lweights_gaussian(data_gaussian)
prob <- edge.prob(W, log = TRUE, account.prior = TRUE, q0 = 0.5)

Run the code above in your browser using DataLab