lweights_gaussian:
Computation of the log-weight matrix in a gaussian setting.
Description
The function computes the log-weights of all edges in a gaussian setting.
The result should be used in edge.prob with argument log set to TRUE.
Usual values are used as default for the prior normal-Wishart hyperparameters.
Computation can be parallelized by setting nbcores to more than 2. Parallelization relies on parallel.
Usage
lweights_gaussian(data, a = ncol(data), mu = numeric(p), au = 1, T = diag(ncol(data), ncol(data)), nbcores = 1)
Arguments
data
Matrix containing continuous data.
a
Prior degree of freedom of the normal-Wishart distribution.
mu
Prior mean for the mean of the normal-Wishart distribution.
au
Prior relative precision of the normal-Wishart distribution.
T
Prior scale matrix of the normal-Wishart distribution.
nbcores
Number of cores to be used in parallelized computation.
References
This package implements the method described in the paper "Bayesian Inference of Graphical Model Structures Using Trees" by L. Schwaller, S. Robin, M. Stumpf, 2015 (submitted and availavable on arXiv).
Examples
Run this codelibrary('saturnin')
data(data_gaussian)
W <- lweights_gaussian(data_gaussian)
prob <- edge.prob(W, log = TRUE)
Run the code above in your browser using DataLab