Learn R Programming

saturnin (version 1.1.1)

saturnin-package: Spanning Trees Used for Network Inference

Description

Bayesian inference of graphical model structures using spanning trees. For further details on the considered framework, we refer the reader to the paper quoted in the references section.

Arguments

Details

Package:
saturnin
Type:
Package
Version:
1.0
Date:
2015-04-10
License:
GPL-2

References

This package implements the method described in the paper "Bayesian Inference of Graphical Model Structures Using Trees" by L. Schwaller, S. Robin, M. Stumpf, 2015 (submitted and availavable on arXiv).

Examples

Run this code
library('saturnin')
data(data_gaussian)

W <- lweights_gaussian(data_gaussian)
prob <- edge.prob(W, log = TRUE, account.prior = TRUE, q0 = 0.5)

Run the code above in your browser using DataLab