edge.prob:
Computation of posterior edge appearance probabilities in a random tree.
Description
The function computes posterior edge appearance probabilities in a random tree from a (log-)weight matrix.
The (log-)weight matrix can be obtained from one of the functions lweights_multinomial, lweights_gaussian or weights_gausscopula.
The function can also account for prior edge appearance probability.
TRUE when using a log-weight matrix, FALSE otherwise.
account.prior
FALSE for no accounting, TRUE otherwise.
q0
Desired prior edge appearance probability.
Value
prob
Posterior edge appearance probability matrix.
References
This package implements the method described in the paper "Bayesian Inference of Graphical Model Structures Using Trees" by L. Schwaller, S. Robin, M. Stumpf, 2015 (submitted and availavable on arXiv).